@@ -12,7 +12,7 @@ use AnyEvent::WebSocket::Connection;
 use PerlX::Maybe qw( maybe provided );
 
 # ABSTRACT: WebSocket client for AnyEvent
-our $VERSION = '0.34_01'; # TRIAL VERSION
+our $VERSION = '0.35_01'; # TRIAL VERSION
 
 
 has timeout => (
@@ -31,6 +31,17 @@ has ssl_ca_file => (
 );
 
 
+has protocol_version => (
+  is => 'ro',
+);
+
+
+has subprotocol => (
+  is     => 'ro',
+  coerce => sub { ref $_[0] ? $_[0] : [$_[0]] },
+);
+
+
 sub connect
 {
   my($self, $uri) = @_;
@@ -58,9 +69,17 @@ sub connect
       return;
     }
     my $handshake = Protocol::WebSocket::Handshake::Client->new(
-      url => $uri->as_string,
+            url     => $uri->as_string,
+      maybe version => $self->protocol_version,
     );
     
+    my %subprotocol;
+    if($self->subprotocol)
+    {
+      %subprotocol = map { $_ => 1 } @{ $self->subprotocol };
+      $handshake->req->subprotocol(join(',', @{ $self->subprotocol }));
+    }
+    
     my $hdl = AnyEvent::Handle->new(
                                                       fh       => $fh,
       provided $uri->secure,                          tls      => 'connect',
@@ -78,7 +97,7 @@ sub connect
                                                         { warn $msg }
                                                       },
     );
-    
+
     $hdl->push_write($handshake->to_string);
     $hdl->on_read(sub {
       $handshake->parse($_[0]{rbuf});
@@ -91,8 +110,30 @@ sub connect
       }
       elsif($handshake->is_done)
       {
+        my $sb;
+        if($self->subprotocol)
+        {
+          $sb = $handshake->res->subprotocol;
+          if(defined $sb)
+          {
+            unless($subprotocol{$sb})
+            {
+              $done->croak("subprotocol mismatch, requested: @{[ join ', ', @{ $self->subprotocol } ]}, got: $sb");
+            }
+          }
+          else
+          {
+            $done->croak("no subprotocol in response");
+          }
+        }
         undef $handshake;
-        $done->send(AnyEvent::WebSocket::Connection->new(handle => $hdl, masked => 1));
+        $done->send(
+          AnyEvent::WebSocket::Connection->new(
+                  handle      => $hdl,
+                  masked      => 1,
+            maybe subprotocol => $sb,
+          )
+        );
         undef $hdl;
         undef $done;
       }
@@ -115,7 +156,7 @@ AnyEvent::WebSocket::Client - WebSocket client for AnyEvent
 
 =head1 VERSION
 
-version 0.34_01
+version 0.35_01
 
 =head1 SYNOPSIS
 
@@ -195,6 +236,16 @@ not be verified.  The default is false.
 Provide your own CA certificates file instead of using the system default for
 SSL/TLS verification.
 
+=head2 protocol_version
+
+The protocol version.  See L<Protocol::WebSocket> for the list of supported
+WebSocket protocol versions.
+
+=head2 subprotocol
+
+List of subprotocols to request from the server.  This class will throw an
+exception if none of the protocols are supported by the server.
+
 =head1 METHODS
 
 =head2 connect
