@@ -11,7 +11,7 @@ use AnyEvent::WebSocket::Message;
 use Carp ();
 
 # ABSTRACT: WebSocket connection for AnyEvent
-our $VERSION = '0.34_01'; # TRIAL VERSION
+our $VERSION = '0.35_01'; # TRIAL VERSION
 
 
 has handle => (
@@ -25,6 +25,11 @@ has masked => (
   default => sub { 0 },
 );
 
+
+has subprotocol => (
+  is => 'ro',
+);
+
 foreach my $type (qw( each_message next_message finish ))
 {
   has "_${type}_cb" => (
@@ -253,7 +258,7 @@ AnyEvent::WebSocket::Connection - WebSocket connection for AnyEvent
 
 =head1 VERSION
 
-version 0.34_01
+version 0.35_01
 
 =head1 SYNOPSIS
 
@@ -311,6 +316,11 @@ Usually only useful for creating server connections, see below.
 
 If set to true, it masks outgoing frames. The default is false.
 
+=head2 subprotocol
+
+The subprotocol returned by the server.  If no subprotocol was requested, it
+may be C<undef>.
+
 =head1 METHODS
 
 =head2 send
